#include "plugincontainer.h"

namespace NPlugin
{

QWidget* PluginContainer::getSettingsWidget(QWidget* pParent)
{
	return 0;
}

void PluginContainer::applySettings()
{
	return;
}

QDomElement PluginContainer::loadSettings(const QDomElement source)
{
	return source;
}

void PluginContainer::saveSettings(NXml::XmlData& outData, QDomElement parent) const
{
}

}	// namespace NPlugin
